pub struct Row {
pub header: u32,
pub image_data: Vec<u8>,
}Expand description
A single row of a frame
Fields
header: u32Compacted header information. It contains the length of the associated data, plus offsets of where to plot, relative to the image center
|x_offset..10bits|y_offset..10bits|run_length..12bits|
The offsets are signed values
image_data: Vec<u8>Individual pixels for the row, as lookups in the AnimGroup palette
Implementations
Sourceimpl Row
impl Row
Sourcepub fn x_offset(&self, image_center_x: i16) -> i32
pub fn x_offset(&self, image_center_x: i16) -> i32
Get the x offset of where to start drawing this row, relative to a center point The resulting offset will be from the bottom left