pub struct RunPair {
pub offset: u16,
pub run: Vec<Color16>,
}Expand description
A run pair contains an offset at which point to start drawing the run, and the pixels to draw
Fields
offset: u16run: Vec<Color16>Trait Implementations
impl Eq for RunPair
impl StructuralPartialEq for RunPair