StaticLocationDiffReader

Struct StaticLocationDiffReader 

pub struct StaticLocationDiffReader<T: Read + Seek> { /* private fields */ }
A struct to help read out static locations for a block from a diff file

Implementations

Source

impl StaticLocationDiffReader<File>

pub fn new( lookup_path: &Path, diff_idx_path: &Path, diff_path: &Path, ) -> MulReaderResult<StaticLocationDiffReader<File>>

Create a new StaticLocationDiffReader from a lookup path, an index path and mul path

Source

impl<T: Read + Seek> StaticLocationDiffReader<T>

pub fn from_mul_reader<U: Read + Seek>( lookup_reader: U, mul_reader: MulReader<T>, lookup_file_length: u32, ) -> MulReaderResult<StaticLocationDiffReader<T>>

Create a StaticLocationDiffReader from existing lookup and mul readers

pub fn read(&mut self, idx: u32) -> Option<MulReaderResult<Vec<StaticLocation>>>

Read statics for a map block, if they exist

pub fn read_all(&mut self) -> HashMap<u32, MulReaderResult<Vec<StaticLocation>>>

Read all static locations