pub struct Cell {
pub graphic: u16,
pub altitude: i8,
}Expand description
An individual tile on a map
Fields
graphic: u16A lookup into art.mul as to what the floor tile should be
altitude: i8How high the floor tile is. When rendering, the reference point is the bottom right, the remaining corners are altered to match the surrounding tiles