StaticLocation

Struct StaticLocation 

pub struct StaticLocation {
    pub object_id: u16,
    pub x: u8,
    pub y: u8,
    pub altitude: i8,
    pub checksum: u16,
}
The location of a fixed map prop, relative to a block

Fields

object_id: u16

A lookup into art.mul, as to what the static should be

x: u8

The x location of the prop

y: u8

The y location of the prop (increasing y means further downwards)

altitude: i8

How high to render this item

checksum: u16

Unused

Implementations

Source

impl StaticLocation

pub fn color_idx(&self) -> u16

Find the position in RadarCol that contains the color to render in the minimap