pub struct MulWriter<T: Write + Seek> { /* private fields */ }Expand description
Write new records onto existing Mul and Idx files
Implementations
Sourceimpl MulWriter<File>
impl MulWriter<File>
Sourcepub fn new(
idx_path: &Path,
mul_path: &Path,
mode: MulWriterMode,
) -> MulWriterResult<MulWriter<File>>
pub fn new( idx_path: &Path, mul_path: &Path, mode: MulWriterMode, ) -> MulWriterResult<MulWriter<File>>
Create a new mul writer from an index and mul path