Module skill

Module skill 

Skill objects represent named skills that appear in UO’s Skills menu. They also contain a flag denoting whether they are clicked to activate

Skills are traditionally stored in skills.mul/skills.idx

Skills are encoded as a list of |clickable:u8|name:c-string|

Structs

Skill
A skill name, plus whether it requires clicking to activate
SkillReader
A struct to help read out Skill data