pub struct MapTileData {
pub flags: Flags,
pub texture_id: u16,
pub name: String,
}Expand description
Information about a given Map tile
Fields
flags: Flagstexture_id: u16Which TexMap to use instead if this tile is non-flat
name: StringTrait Implementations
Sourceimpl Clone for MapTileData
impl Clone for MapTileData
Sourcefn clone(&self) -> MapTileData
fn clone(&self) -> MapTileData
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for MapTileData
impl Debug for MapTileData
Sourceimpl PartialEq for MapTileData
impl PartialEq for MapTileData
Sourcefn eq(&self, other: &MapTileData) -> bool
fn eq(&self, other: &MapTileData) -> bool
Tests for
self and other values to be equal, and is used by ==.impl Eq for MapTileData
impl StructuralPartialEq for MapTileData