pub struct StaticTileData {
pub flags: Flags,
pub weight: u8,
pub quality_layer_light_id: u8,
pub quantity_weapon_class_armor_class: u8,
pub anim_id: u16,
pub hue: u8,
pub height_capacity: u8,
pub name: String,
}Expand description
Information about a given Static tile
Fields
flags: Flagsweight: u8quality_layer_light_id: u8This field becomes Layer for wearables, and the Light ID for lights, otherwise quality.
quantity_weapon_class_armor_class: u8This field becomes weapon class for weapons, armor class for armor, or defaults to quantity.
anim_id: u16hue: u8height_capacity: u8This field becomes capacity for containers, otherwise height
name: StringTrait Implementations
Sourceimpl Clone for StaticTileData
impl Clone for StaticTileData
Sourcefn clone(&self) -> StaticTileData
fn clone(&self) -> StaticTileData
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for StaticTileData
impl Debug for StaticTileData
Sourceimpl PartialEq for StaticTileData
impl PartialEq for StaticTileData
Sourcefn eq(&self, other: &StaticTileData) -> bool
fn eq(&self, other: &StaticTileData) -> bool
Tests for
self and other values to be equal, and is used by ==.impl Eq for StaticTileData
impl StructuralPartialEq for StaticTileData