Methods for reading map files from the various map muls
Maps are stored as single, unindexed files. They contain a sequence of blocks:
|checksum:u32|cells:[Block..64]
And blocks are stored as
|graphic:u16|altitude:i8|
You need to know the dimensions of the map to read it correctly;
some of these are stored in map_size
Modules
- diff
- Methods for reading patches over a map from mapdifl (the lookup file) and mapdif (the data). This module also provides methods for reading static patches from stadifl (lookup), stadifi (index) and stadif (data)
- map_
size - Constants for map sizes, in blocks
- radarcol
- Methods for reading radar colors from radarcol.mul
- static_
location - Methods for reading static prop locations from muls
Structs
- Block
- A block. Blocks contain a grid of 8x8 cells.
- Cell
- An individual tile on a map
- MapReader
- A struct to help read out Map data
- Static
Location - The location of a fixed map prop, relative to a block