Module diff

Module diff 

Methods for reading patches over a map from mapdifl (the lookup file) and mapdif (the data). This module also provides methods for reading static patches from stadifl (lookup), stadifi (index) and stadif (data)

For both types of lookup files, the format is simple

|lookups:[u32..file_size]|

Each lookup value represents a block index in the map file, while their index represents the appropriate index in the patch data files. In the static files, the index instead represents a lookup into the index file.

mapdif files are internally structured as a list of blocks. stadif and stadifl are structured the same way as the static locations files.

Structs

MapDiffReader
A struct to help read out map blocks from a diff file
StaticLocationDiffReader
A struct to help read out static locations for a block from a diff file