pub struct StaticLocationDiffReader<T: Read + Seek> { /* private fields */ }Expand description
A struct to help read out static locations for a block from a diff file
Implementations
Sourceimpl StaticLocationDiffReader<File>
impl StaticLocationDiffReader<File>
Sourcepub fn new(
lookup_path: &Path,
diff_idx_path: &Path,
diff_path: &Path,
) -> MulReaderResult<StaticLocationDiffReader<File>>
pub fn new( lookup_path: &Path, diff_idx_path: &Path, diff_path: &Path, ) -> MulReaderResult<StaticLocationDiffReader<File>>
Create a new StaticLocationDiffReader from a lookup path, an index path and mul path
Sourceimpl<T: Read + Seek> StaticLocationDiffReader<T>
impl<T: Read + Seek> StaticLocationDiffReader<T>
Sourcepub fn from_mul_reader<U: Read + Seek>(
lookup_reader: U,
mul_reader: MulReader<T>,
lookup_file_length: u32,
) -> MulReaderResult<StaticLocationDiffReader<T>>
pub fn from_mul_reader<U: Read + Seek>( lookup_reader: U, mul_reader: MulReader<T>, lookup_file_length: u32, ) -> MulReaderResult<StaticLocationDiffReader<T>>
Create a StaticLocationDiffReader from existing lookup and mul readers
Sourcepub fn read(&mut self, idx: u32) -> Option<MulReaderResult<Vec<StaticLocation>>>
pub fn read(&mut self, idx: u32) -> Option<MulReaderResult<Vec<StaticLocation>>>
Read statics for a map block, if they exist
Sourcepub fn read_all(&mut self) -> HashMap<u32, MulReaderResult<Vec<StaticLocation>>>
pub fn read_all(&mut self) -> HashMap<u32, MulReaderResult<Vec<StaticLocation>>>
Read all static locations