Module static_location

Module static_location 

Methods for reading static prop locations from muls

Each index location maps directly to a block in the map files. Each mul record represents all of the static objects in a block, as a list of StaticLocations

A StaticLocation is defined as

|object_id:u16|x:y8|y:u8|altitude:i8|

As with MapReader, methods allow the passing of a patch reader to simplify applying patches.

Structs

StaticLocationReader
A struct to help read out Static locations for a map