pub struct Block {
pub checksum: u32,
pub cells: [Cell; 64],
}Expand description
A block. Blocks contain a grid of 8x8 cells.
Blocks are stored in Maps in columns, top to bottom, left to right
Fields
checksum: u32Unused
cells: [Cell; 64]An 8x8 grid of cells, stored in rows. The first row is the top of the block, working downwards