pub struct MulRecord {
pub data: Vec<u8>,
pub start: u32,
pub length: u32,
pub opt1: u16,
pub opt2: u16,
}Expand description
An individual record, read from a Mul file
Fields
data: Vec<u8>Raw Mul data
start: u32The index position in the Mul of this item
length: u32The total length in the Mul of this item
opt1: u16An implementation-specific variable
opt2: u16An implementation-specific variable