StaticTileData

Struct StaticTileData 

pub struct StaticTileData {
    pub flags: Flags,
    pub weight: u8,
    pub quality_layer_light_id: u8,
    pub quantity_weapon_class_armor_class: u8,
    pub anim_id: u16,
    pub hue: u8,
    pub height_capacity: u8,
    pub name: String,
}
Information about a given Static tile

Fields

flags: Flagsweight: u8quality_layer_light_id: u8

This field becomes Layer for wearables, and the Light ID for lights, otherwise quality.

quantity_weapon_class_armor_class: u8

This field becomes weapon class for weapons, armor class for armor, or defaults to quantity.

anim_id: u16hue: u8height_capacity: u8

This field becomes capacity for containers, otherwise height

name: String